@@ -80,6 +80,11 @@ class DumpResult:
 
 import sqlite3
 from .sqlite_utils import create_schema
+import pickle
+
+sqlite3.register_converter("pickle", pickle.loads)
+sqlite3.register_adapter(list, pickle.dumps)
+sqlite3.register_adapter(set, pickle.dumps)
 
 class DumpResultSqlite(DumpResult):
 	def __init__(self, sqlite_path, commit_frequency = 50):
@@ -118,6 +123,7 @@ class DumpResultSqlite(DumpResult):
 		insert_keys = self.to_insert.keys()
 
 		for key in insert_keys:
+			# create a new saved copy in the db:
 			self.insert_into_db(self.cursor,
 				(
 					self.targets[key],
@@ -132,11 +138,15 @@ class DumpResultSqlite(DumpResult):
 		update_keys = self.to_update.keys()
 
 		for key in update_keys:
+			# get previous saved copy:
+			old_key, lines, parents  = self.get_obj_from_db(self.cursor, self.targets[key])
+
+			# update that copy
 			self.update_in_db(self.cursor,
 				(
 					self.targets[key],
-					self.to_update[key],
-					set(self.to_update_parents[key])
+					lines + self.to_update[key],
+					parents + self.to_update_parents[key]
 				)
 			)
 			del self.to_update[key]
